package com.ruoyi.system.service.impl.fgw;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.fgw.FgwJdapFjMapper;
import com.ruoyi.system.domain.fgw.FgwJdapFj;
import com.ruoyi.system.service.fgw.IFgwJdapFjService;

/**
 * 发改委_节点安排_附件Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-04-11
 */
@Service
public class FgwJdapFjServiceImpl implements IFgwJdapFjService 
{
    @Autowired
    private FgwJdapFjMapper fgwJdapFjMapper;

    /**
     * 查询发改委_节点安排_附件
     * 
     * @param id 发改委_节点安排_附件主键
     * @return 发改委_节点安排_附件
     */
    @Override
    public FgwJdapFj selectFgwJdapFjById(Long id)
    {
        return fgwJdapFjMapper.selectFgwJdapFjById(id);
    }

    /**
     * 查询发改委_节点安排_附件列表
     * 
     * @param fgwJdapFj 发改委_节点安排_附件
     * @return 发改委_节点安排_附件
     */
    @Override
    public List<FgwJdapFj> selectFgwJdapFjList(FgwJdapFj fgwJdapFj)
    {
        return fgwJdapFjMapper.selectFgwJdapFjList(fgwJdapFj);
    }

    /**
     * 新增发改委_节点安排_附件
     * 
     * @param fgwJdapFj 发改委_节点安排_附件
     * @return 结果
     */
    @Override
    public int insertFgwJdapFj(FgwJdapFj fgwJdapFj)
    {
        return fgwJdapFjMapper.insertFgwJdapFj(fgwJdapFj);
    }

    /**
     * 修改发改委_节点安排_附件
     * 
     * @param fgwJdapFj 发改委_节点安排_附件
     * @return 结果
     */
    @Override
    public int updateFgwJdapFj(FgwJdapFj fgwJdapFj)
    {
        return fgwJdapFjMapper.updateFgwJdapFj(fgwJdapFj);
    }

    /**
     * 批量删除发改委_节点安排_附件
     * 
     * @param ids 需要删除的发改委_节点安排_附件主键
     * @return 结果
     */
    @Override
    public int deleteFgwJdapFjByIds(Long[] ids)
    {
        return fgwJdapFjMapper.deleteFgwJdapFjByIds(ids);
    }

    /**
     * 删除发改委_节点安排_附件信息
     * 
     * @param id 发改委_节点安排_附件主键
     * @return 结果
     */
    @Override
    public int deleteFgwJdapFjById(Long id)
    {
        return fgwJdapFjMapper.deleteFgwJdapFjById(id);
    }
}
